@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2021 openpyxl
 
 from openpyxl.compat import safe_string
 from openpyxl.descriptors import (
@@ -76,7 +75,7 @@ class Border(Serialisable):
     left = Typed(expected_type=Side, allow_none=True)
     right = Typed(expected_type=Side, allow_none=True)
     top = Typed(expected_type=Side, allow_none=True)
-    bottom = Typed(expected_type=Side)
+    bottom = Typed(expected_type=Side, allow_none=True)
     diagonal = Typed(expected_type=Side, allow_none=True)
     vertical = Typed(expected_type=Side, allow_none=True)
     horizontal = Typed(expected_type=Side, allow_none=True)
@@ -85,8 +84,8 @@ class Border(Serialisable):
     diagonalUp = Bool()
     diagonalDown = Bool()
 
-    def __init__(self, left=Side(), right=Side(), top=Side(),
-                 bottom=Side(), diagonal=Side(), diagonal_direction=None,
+    def __init__(self, left=None, right=None, top=None,
+                 bottom=None, diagonal=None, diagonal_direction=None,
                  vertical=None, horizontal=None, diagonalUp=False, diagonalDown=False,
                  outline=True, start=None, end=None):
         self.left = left
@@ -111,4 +110,4 @@ class Border(Serialisable):
             elif attr == "outline" and not value:
                 yield attr, safe_string(value)
 
-DEFAULT_BORDER = Border()
+DEFAULT_BORDER = Border(left=Side(), right=Side(), top=Side(), bottom=Side(), diagonal=Side())
