@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2014 openpyxl
+# Copyright (c) 2010-2021 openpyxl
 
 import pytest
 
@@ -10,7 +10,7 @@ def Alignment():
 
 def test_default(Alignment):
     al = Alignment()
-    assert dict(al) == {'horizontal':'general', 'vertical':'bottom'}
+    assert dict(al) == {}
 
 
 def test_round_trip(Alignment):
@@ -21,7 +21,6 @@ def test_round_trip(Alignment):
 
 def test_alias(Alignment):
     al = Alignment(text_rotation=90, shrink_to_fit=True, wrap_text=True)
-    assert dict(al) == {'horizontal':'general', 'vertical':'bottom',
-                        'textRotation':'90',
-                        'shrinkToFit':'1',
-                        'wrapText':'1'}
+    assert dict(al) == { 'textRotation':'90',
+                         'shrinkToFit':'1',
+                         'wrapText':'1'}
