@@ -1,38 +1,47 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2014 openpyxl
+# Copyright (c) 2010-2021 openpyxl
 
-from openpyxl.descriptors import Strict, Bool, String, Alias, Integer
-from openpyxl.compat import safe_string
+from openpyxl.descriptors import (
+    Bool,
+    String,
+    Alias,
+    Integer,
+)
+from openpyxl.descriptors.serialisable import Serialisable
+from openpyxl.descriptors.excel import (
+    Base64Binary,
+)
+from openpyxl.utils.protection import hash_password
 
 
-def hash_password(plaintext_password=''):
-    """
-    Create a password hash from a given string for protecting a worksheet
-    only. This will not work for encrypting a workbook.
+class _Protected(object):
+    _password = None
 
-    This method is based on the algorithm provided by
-    Daniel Rentz of OpenOffice and the PEAR package
-    Spreadsheet_Excel_Writer by Xavier Noguer <xnoguer@rezebra.com>.
-    See also http://blogs.msdn.com/b/ericwhite/archive/2008/02/23/the-legacy-hashing-algorithm-in-open-xml.aspx
-    """
-    password = 0x0000
-    for idx, char in enumerate(plaintext_password, 1):
-        value = ord(char) << idx
-        rotated_bits = value >> 15
-        value &= 0x7fff
-        password ^= (value | rotated_bits)
-    password ^= len(plaintext_password)
-    password ^= 0xCE4B
-    return str(hex(password)).upper()[2:]
+    def set_password(self, value='', already_hashed=False):
+        """Set a password on this sheet."""
+        if not already_hashed:
+            value = hash_password(value)
+        self._password = value
+
+    @property
+    def password(self):
+        """Return the password value, regardless of hash."""
+        return self._password
+
+    @password.setter
+    def password(self, value):
+        """Set a password directly, forcing a hash step."""
+        self.set_password(value)
 
 
-class SheetProtection(Strict):
+class SheetProtection(Serialisable, _Protected):
     """
     Information about protection of various aspects of a sheet. True values
     mean that protection for the object or action is active This is the
     **default** when protection is active, ie. users cannot do something
     """
 
+    tagname = "sheetProtection"
+
     sheet = Bool()
     enabled = Alias('sheet')
     objects = Bool()
@@ -50,11 +59,17 @@ class SheetProtection(Strict):
     sort = Bool()
     autoFilter = Bool()
     pivotTables = Bool()
-    saltValue = String(allow_none=True)
+    saltValue = Base64Binary(allow_none=True)
     spinCount = Integer(allow_none=True)
     algorithmName = String(allow_none=True)
+    hashValue = Base64Binary(allow_none=True)
 
-    _password = None
+
+    __attrs__ = ('selectLockedCells', 'selectUnlockedCells', 'algorithmName',
+              'sheet', 'objects', 'insertRows', 'insertHyperlinks', 'autoFilter',
+              'scenarios', 'formatColumns', 'deleteColumns', 'insertColumns',
+              'pivotTables', 'deleteRows', 'formatCells', 'saltValue', 'formatRows',
+              'sort', 'spinCount', 'password', 'hashValue')
 
 
     def __init__(self, sheet=False, objects=False, scenarios=False,
@@ -62,7 +77,7 @@ class SheetProtection(Strict):
                  insertColumns=True, insertRows=True, insertHyperlinks=True,
                  deleteColumns=True, deleteRows=True, selectLockedCells=False,
                  selectUnlockedCells=False, sort=True, autoFilter=True, pivotTables=True,
-                 password=None, algorithmName=None, saltValue=None, spinCount=None):
+                 password=None, algorithmName=None, saltValue=None, spinCount=None, hashValue=None):
         self.sheet = sheet
         self.objects = objects
         self.scenarios = scenarios
@@ -80,29 +95,17 @@ class SheetProtection(Strict):
         self.autoFilter = autoFilter
         self.pivotTables = pivotTables
         if password is not None:
-            self.set_password(password)
+            self.password = password
         self.algorithmName = algorithmName
         self.saltValue = saltValue
         self.spinCount = spinCount
+        self.hashValue = hashValue
 
 
     def set_password(self, value='', already_hashed=False):
-        """Set a password on this sheet."""
-        if not already_hashed:
-            value = hash_password(value)
-        self._password = value
+        super(SheetProtection, self).set_password(value, already_hashed)
         self.enable()
 
-    @property
-    def password(self):
-        """Return the password value, regardless of hash."""
-        return self._password
-
-    @password.setter
-    def password(self, value):
-        """Set a password directly, forcing a hash step."""
-        self.set_password(value, already_hashed=False)
-
 
     def enable(self):
         self.sheet = True
@@ -112,12 +115,6 @@ class SheetProtection(Strict):
         self.sheet = False
 
 
-    def __iter__(self):
-        for key in ('sheet', 'objects', 'scenarios', 'formatCells',
-                  'formatRows', 'formatColumns', 'insertColumns', 'insertRows',
-                  'insertHyperlinks', 'deleteColumns', 'deleteRows',
-                  'selectLockedCells', 'selectUnlockedCells', 'sort', 'autoFilter',
-                  'pivotTables', 'password', 'algorithmName', 'saltValue', 'spinCount'):
-            value = getattr(self, key)
-            if value is not None:
-                yield key, safe_string(value)
+    def  __bool__(self):
+        return self.sheet
+
